
####################################################################
# Circualr kernel density models for estimating activity levels and patterns
# Comparison of activities of co-occurring and single-species detections
#################################################################### 
# Set and examine the working directory prior analysis
setwd(choose.dir("E:/Camera_course/Serow overlap"))
getwd()
## Load package "activity" (Version 1.1) and package overlap (Version 0.3.2)
library(activity)
library(overlap)
# Input co-occurring detection data
co_occurring <- read.table("Co-occur.csv", header=TRUE, sep=',')
# Input single-species detection data of red serow
rs <- read.table("rs-occur.csv", header=TRUE, sep=',')
# Input single-species detection data of Chineses serow
cs <- read.table("cs-occur.csv", header=TRUE, sep=',')
# Extract the radian suntime data for the co-occurring and single-species detections
co_time<-co_occurring$RadianSunTime
rs_time<-rs$RadianSunTime
cs_time<-cs$RadianSunTime
# Summary of the co-occurring data
summary(co_time)
str(co_time)
range(co_time)
# Summary of red serows single-species data
summary(rs_time)
str(rs_time)
range(rs_time)
# Summary of Chinese serows single-species data
summary(cs_time)
str(cs_time)
range(cs_time)


#################################################################### 
# Circular kernel density models on the original dataset are fitted 
# The coverage of the confidence interval seems to be better estimated
# with sample = "model" when the sample size is greater than 100-200, 
# whereas smaller sample sizes should be investigated using sample = "data"
co_actmod<-fitact(co_time,adj=1, sample="data", reps=10000)
co_actmod
rs_actmod<-fitact(rs_time,adj=1.5, sample="model", reps=10000)
rs_actmod
cs_actmod<-fitact(cs_time,adj=1.5, sample="model", reps=10000)
cs_actmod
# Randomization Test for activity patterns
compareCkern(co_time, rs_time, reps = 10000, index = c("Dhat1")) #package version 1.1 Dhat1
compareCkern(co_time, cs_time, reps = 10000, index = c("Dhat1")) #package version 1.1 Dhat1
# Wald test using the function compareAct(fits) to estimate
# the significance of pairwise comparisons
compareAct(list(co_actmod,rs_actmod))
compareAct(list(co_actmod,cs_actmod))

#################################################################### 
# Get the size of the smaller of the two samples type
min(length(co_time), length(rs_time), length(cs_time))
# Calculate the overlap with the three estimators
# Coefficient of overlapping between Co-detection data and red serow's solitary detection data
overlap_estimation_1<-overlapEst(co_time,rs_time, adjust = 1.5)
overlap_estimation_1
# Plot the curves
overlapPlot(co_time,rs_time, rug=T, main="",adjust=1.5,
            linetype=c(1,5), linecol=c("black","red"),linewidth = c(2, 2),
            extend="grey60", olapcol = "lightgrey",ylim=c(0,0.1),
            cex.axis=1.5, cex.lab=1.5,
            ylab = "Kernel Density Estimate", xlab = "Time of Day")
legend('topright', c("Co-occurrence", "Red serow alone"), 
       lwd=2, lty=c(1,2), col=c("black","red"), bty='n',cex=1.25)
####################################################################
# Bootstrap analysis to estimate the CI of the coefficient of overlapping
# Generate 10000 smoothed bootstrap for red serow and Chinese serow
co_time_boot<-resample(co_time,10000)
rs_time_boot<-resample(rs_time, 10000)
dim(co_time_boot)
dim(rs_time_boot)
# To generate estimates of overlap from each pair of samples
# these two matrices are passed to the function bootEst()
bootstrap_estimation_1<-bootEst(co_time_boot, rs_time_boot, adjust=c(1,1,NA))
head(bootstrap_estimation_1)
dim(bootstrap_estimation_1)
BSmean_1<-colMeans(bootstrap_estimation_1)
BSmean_1 # Get mean value of Dhat4 estimator
## Corrections on a logistic scale and back transforming
## Use "basic0" from resampling matrix as credible interval(CI)
tmp_1<-bootstrap_estimation_1[,2]
bootCIlogit(overlap_estimation_1[2],tmp_1)

#################################################################### 
# Calculate the overlap with the three estimators
# Coefficient of overlapping between Co-detection data and Chinese serow's solitary detection data
overlap_estimation_2<-overlapEst(co_time,cs_time, adjust = 1.5)
overlap_estimation_2
# Plot the curves
overlapPlot(co_time,cs_time, rug=T, main="",adjust=1.5,
            linetype=c(1,5), linecol=c("black","blue"),linewidth = c(2, 2),
            extend="grey60", olapcol = "lightgrey",ylim=c(0,0.1),
            cex.axis=1.5, cex.lab=1.5,
            ylab = "Kernel Density Estimate", xlab = "Time of Day")
legend('topright', c("Co-occurrence", "Chinese serow alone"), 
       lwd=2, lty=c(1,2), col=c("black","blue"), bty='n',cex=1.25)
####################################################################
# Bootstrap analysis to estimate the CI of the coefficient of overlapping
# Generate 10000 smoothed bootstrap for red serow and Chinese serow
co_time_boot<-resample(co_time,10000)
cs_time_boot<-resample(cs_time, 10000)
dim(co_time_boot)
dim(cs_time_boot)
# To generate estimates of overlap from each pair of samples
# these two matrices are passed to the function bootEst()
bootstrap_estimation_2<-bootEst(co_time_boot, cs_time_boot, adjust=c(1,1,NA))
head(bootstrap_estimation_2)
dim(bootstrap_estimation_2)
BSmean_2<-colMeans(bootstrap_estimation_2)
BSmean_2 # Get mean value of Dhat4 estimator
## Corrections on a logistic scale and back transforming
## Use "basic0" from resampling matrix as credible interval(CI)
tmp_2<-bootstrap_estimation_2[,2]
bootCIlogit(overlap_estimation_2[2],tmp_2)

